==> jakarta-xml-ws-tck-2.3.0.zip: xml-ws-tck/src/com/sun/ts/tests/jaxws/ee/w2j/document/literal/handlerchaintest/Client.java <==
/*
 * Copyright (c) 2007, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

/*
 *  $Id$
 */
package com.sun.ts.tests.jaxws.ee.w2j.document.literal.handlerchaintest;

import com.sun.ts.lib.util.*;
import com.sun.ts.lib.porting.*;
import com.sun.ts.lib.harness.*;
import com.sun.javatest.Status;

import java.io.*;
import java.net.*;
import java.util.*;
import java.rmi.*;

import javax.xml.ws.*;
import java.util.Properties;
import com.sun.ts.tests.jaxws.common.*;

import javax.xml.namespace.QName;
import javax.xml.bind.JAXBContext;

public class Client extends ServiceEETest {

  private static final ObjectFactory of = new ObjectFactory();

  // The webserver defaults (overidden by harness properties)
  private static final String PROTOCOL = "http";

  private static final String HOSTNAME = "localhost";

  private static final int PORTNUM = 8000;

  // The webserver host and port property names (harness properties)
  private static final String WEBSERVERHOSTPROP = "webServerHost";

  private static final String WEBSERVERPORTPROP = "webServerPort";

  private static final String MODEPROP = "platform.mode";

  // ServiceName and PortName mapping configuration going java-to-wsdl
  private static final String SERVICE_NAME = "HandlerChainTestService";

  private static final String PORT_NAME = "HandlerChainTestPort";

  private static final String NAMESPACEURI = "http://handlerchaintestservice.org/wsdl";

  private QName SERVICE_QNAME = new QName(NAMESPACEURI, SERVICE_NAME);

  private QName PORT_QNAME = new QName(NAMESPACEURI, PORT_NAME);

  // URL properties used by the test
  private static final String ENDPOINT_URL = "w2jdlhandlerchaintest.endpoint.1";

  private static final String WSDLLOC_URL = "w2jdlhandlerchaintest.wsdlloc.1";

  private String url = null;

  private URL wsdlurl = null;

  private String hostname = HOSTNAME;

  private int portnum = PORTNUM;

  String modeProperty = null; // platform.mode -> (standalone|javaEE)

  HandlerChainTest port = null;

  static HandlerChainTestService service = null;

  private TSURL ctsurl = new TSURL();

  private Dispatch<Object> dispatchJaxb = null;

  private static final Class SERVICE_CLASS = com.sun.ts.tests.jaxws.ee.w2j.document.literal.handlerchaintest.HandlerChainTestService.class;

  private static final Class JAXB_OBJECT_FACTORY = com.sun.ts.tests.jaxws.ee.w2j.document.literal.handlerchaintest.ObjectFactory.class;

  private JAXBContext createJAXBContext() {
    try {
      return JAXBContext.newInstance(JAXB_OBJECT_FACTORY);
    } catch (javax.xml.bind.JAXBException e) {
      throw new WebServiceException(e.getMessage(), e);
    }
  }

  private Dispatch<Object> createDispatchJAXB() throws Exception {
    return service.createDispatch(PORT_QNAME, createJAXBContext(),
        javax.xml.ws.Service.Mode.PAYLOAD);
  }

  private void getTestURLs() throws Exception {
    TestUtil.logMsg("Get URL's used by the test");
    String file = JAXWS_Util.getURLFromProp(ENDPOINT_URL);
    url = ctsurl.getURLString(PROTOCOL, hostname, portnum, file);
    file = JAXWS_Util.getURLFromProp(WSDLLOC_URL);
    wsdlurl = ctsurl.getURL(PROTOCOL, hostname, portnum, file);
    TestUtil.logMsg("Service Endpoint URL: " + url);
    TestUtil.logMsg("WSDL Location URL:    " + wsdlurl);
  }

  private void getPortJavaEE() throws Exception {
    port = (HandlerChainTest) service.getHandlerChainTestPort();
    TestUtil.logMsg("port=" + port);
    TestUtil.logMsg("Obtained port");
    JAXWS_Util.dumpTargetEndpointAddress(port);
  }

  private void getPortStandalone() throws Exception {
    service = (HandlerChainTestService) JAXWS_Util.getService(wsdlurl,
        SERVICE_QNAME, SERVICE_CLASS);
  }

  private void getTargetEndpointAddress(Object port) throws Exception {
    TestUtil.logMsg("Get Target Endpoint Address for port=" + port);
    String url = JAXWS_Util.getTargetEndpointAddress(port);
    TestUtil.logMsg("Target Endpoint Address=" + url);
  }

  public static void main(String[] args) {
    Client theTests = new Client();
    Status s = theTests.run(args, System.out, System.err);
    s.exit();
  }

  /* Test setup */

  /*
   * @class.testArgs: -ap jaxws-url-props.dat
   * 
   * @class.setup_props: webServerHost; webServerPort; platform.mode;
   */

  public void setup(String[] args, Properties p) throws Fault {
    boolean pass = true;

    try {
      hostname = p.getProperty(WEBSERVERHOSTPROP);

      if (hostname == null)
        pass = false;
      else if (hostname.equals(""))
        pass = false;

      try {
        portnum = Integer.parseInt(p.getProperty(WEBSERVERPORTPROP));
      } catch (Exception e) {
        TestUtil.printStackTrace(e);
        pass = false;
      }
      modeProperty = p.getProperty(MODEPROP);
      if (modeProperty.equals("standalone")) {
        getTestURLs();
        getPortStandalone();
      } else {
        TestUtil.logMsg(
            "WebServiceRef is not set in Client (get it from specific vehicle)");
        service = (HandlerChainTestService) getSharedObject();
        getTestURLs();
        getPortJavaEE();
      }
    } catch (Exception e) {
      TestUtil.printStackTrace(e);
      throw new Fault("setup failed:", e);
    }

    if (!pass) {
      TestUtil.logErr(
          "Please specify host & port of web server " + "in config properties: "
              + WEBSERVERHOSTPROP + ", " + WEBSERVERPORTPROP);
      throw new Fault("setup failed:");
    }

    logMsg("setup ok");
  }

  public void cleanup() throws Fault {
    logMsg("cleanup ok");
  }

  /*
   * @testName: HandlerChainOnProviderTest
   *
   * @assertion_ids: JAXWS:SPEC:9009.2
   *
   * @test_Strategy: Use a handler that is specified on the Provider and see
   * that it transforms the body
   */
  public void HandlerChainOnProviderTest() throws Fault {
    TestUtil.logMsg("HandlerChainOnProviderTest");
    boolean pass = true;
    String expected1 = "OutboundServerLogicalHandler";
    String expected2 = "InboundServerLogicalHandler";
    String expected3 = "InboundServerSOAPHandler";
    String expected4 = "OutboundServerSOAPHandler";

    HelloRequest helloReq = null;
    try {
      helloReq = of.createHelloRequest();
      helloReq.setArgument("HandlerChainOnProviderTest");
    } catch (Exception e) {
      e.printStackTrace();
    }
    HelloResponse helloRes = null;
    try {
      dispatchJaxb = createDispatchJAXB();
      helloRes = (HelloResponse) dispatchJaxb.invoke(helloReq);
      String result = helloRes.getArgument();
      TestUtil.logMsg("Return value = " + result);
      if (result.indexOf(expected1) == -1) {
        pass = false;
        TestUtil.logErr("The value:" + expected1 + " was not found ");
        TestUtil.logErr("in the result:" + result);
      }
      if (result.indexOf(expected2) == -1) {
        pass = false;
        TestUtil.logErr("The value:" + expected2 + " was not found ");
        TestUtil.logErr("in the result:" + result);
      }
      if (result.indexOf(expected3) == -1) {
        pass = false;
        TestUtil.logErr("The value:" + expected3 + " was not found ");
        TestUtil.logErr("in the result:" + result);
      }
      if (result.indexOf(expected4) == -1) {
        pass = false;
        TestUtil.logErr("The value:" + expected4 + " was not found ");
        TestUtil.logErr("in the result:" + result);
      }
    } catch (Throwable t) {
      t.printStackTrace();
      throw new Fault(t.toString());
    }

    if (!pass)
      throw new Fault("HandlerChainOnProviderTest failed");
  }

}

==> jakarta-xml-ws-tck-4.0.1.zip: xml-ws-tck/src/com/sun/ts/tests/jaxws/ee/w2j/document/literal/handlerchaintest/Client.java <==
/*
 * Copyright (c) 2007, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

/*
 *  $Id$
 */
package com.sun.ts.tests.jaxws.ee.w2j.document.literal.handlerchaintest;

import com.sun.ts.lib.util.*;
import com.sun.ts.lib.porting.*;
import com.sun.ts.lib.harness.*;
import com.sun.javatest.Status;

import java.io.*;
import java.net.*;
import java.util.*;
import java.rmi.*;

import jakarta.xml.ws.*;
import java.util.Properties;
import com.sun.ts.tests.jaxws.common.*;

import javax.xml.namespace.QName;
import jakarta.xml.bind.JAXBContext;

public class Client extends ServiceEETest {

  private static final ObjectFactory of = new ObjectFactory();

  // The webserver defaults (overidden by harness properties)
  private static final String PROTOCOL = "http";

  private static final String HOSTNAME = "localhost";

  private static final int PORTNUM = 8000;

  // The webserver host and port property names (harness properties)
  private static final String WEBSERVERHOSTPROP = "webServerHost";

  private static final String WEBSERVERPORTPROP = "webServerPort";

  private static final String MODEPROP = "platform.mode";

  // ServiceName and PortName mapping configuration going java-to-wsdl
  private static final String SERVICE_NAME = "HandlerChainTestService";

  private static final String PORT_NAME = "HandlerChainTestPort";

  private static final String NAMESPACEURI = "http://handlerchaintestservice.org/wsdl";

  private QName SERVICE_QNAME = new QName(NAMESPACEURI, SERVICE_NAME);

  private QName PORT_QNAME = new QName(NAMESPACEURI, PORT_NAME);

  // URL properties used by the test
  private static final String ENDPOINT_URL = "w2jdlhandlerchaintest.endpoint.1";

  private static final String WSDLLOC_URL = "w2jdlhandlerchaintest.wsdlloc.1";

  private String url = null;

  private URL wsdlurl = null;

  private String hostname = HOSTNAME;

  private int portnum = PORTNUM;

  String modeProperty = null; // platform.mode -> (standalone|jakartaEE)

  HandlerChainTest port = null;

  static HandlerChainTestService service = null;

  private TSURL ctsurl = new TSURL();

  private Dispatch<Object> dispatchJaxb = null;

  private static final Class SERVICE_CLASS = com.sun.ts.tests.jaxws.ee.w2j.document.literal.handlerchaintest.HandlerChainTestService.class;

  private static final Class JAXB_OBJECT_FACTORY = com.sun.ts.tests.jaxws.ee.w2j.document.literal.handlerchaintest.ObjectFactory.class;

  private JAXBContext createJAXBContext() {
    try {
      return JAXBContext.newInstance(JAXB_OBJECT_FACTORY);
    } catch (jakarta.xml.bind.JAXBException e) {
      throw new WebServiceException(e.getMessage(), e);
    }
  }

  private Dispatch<Object> createDispatchJAXB() throws Exception {
    return service.createDispatch(PORT_QNAME, createJAXBContext(),
        jakarta.xml.ws.Service.Mode.PAYLOAD);
  }

  private void getTestURLs() throws Exception {
    TestUtil.logMsg("Get URL's used by the test");
    String file = JAXWS_Util.getURLFromProp(ENDPOINT_URL);
    url = ctsurl.getURLString(PROTOCOL, hostname, portnum, file);
    file = JAXWS_Util.getURLFromProp(WSDLLOC_URL);
    wsdlurl = ctsurl.getURL(PROTOCOL, hostname, portnum, file);
    TestUtil.logMsg("Service Endpoint URL: " + url);
    TestUtil.logMsg("WSDL Location URL:    " + wsdlurl);
  }

  private void getPortJavaEE() throws Exception {
    port = (HandlerChainTest) service.getHandlerChainTestPort();
    TestUtil.logMsg("port=" + port);
    TestUtil.logMsg("Obtained port");
    JAXWS_Util.dumpTargetEndpointAddress(port);
  }

  private void getPortStandalone() throws Exception {
    service = (HandlerChainTestService) JAXWS_Util.getService(wsdlurl,
        SERVICE_QNAME, SERVICE_CLASS);
  }

  private void getTargetEndpointAddress(Object port) throws Exception {
    TestUtil.logMsg("Get Target Endpoint Address for port=" + port);
    String url = JAXWS_Util.getTargetEndpointAddress(port);
    TestUtil.logMsg("Target Endpoint Address=" + url);
  }

  public static void main(String[] args) {
    Client theTests = new Client();
    Status s = theTests.run(args, System.out, System.err);
    s.exit();
  }

  /* Test setup */

  /*
   * @class.testArgs: -ap jaxws-url-props.dat
   * 
   * @class.setup_props: webServerHost; webServerPort; platform.mode;
   */

  public void setup(String[] args, Properties p) throws Fault {
    boolean pass = true;

    try {
      hostname = p.getProperty(WEBSERVERHOSTPROP);

      if (hostname == null)
        pass = false;
      else if (hostname.equals(""))
        pass = false;

      try {
        portnum = Integer.parseInt(p.getProperty(WEBSERVERPORTPROP));
      } catch (Exception e) {
        TestUtil.printStackTrace(e);
        pass = false;
      }
      modeProperty = p.getProperty(MODEPROP);
      if (modeProperty.equals("standalone")) {
        getTestURLs();
        getPortStandalone();
      } else {
        TestUtil.logMsg(
            "WebServiceRef is not set in Client (get it from specific vehicle)");
        service = (HandlerChainTestService) getSharedObject();
        getTestURLs();
        getPortJavaEE();
      }
    } catch (Exception e) {
      TestUtil.printStackTrace(e);
      throw new Fault("setup failed:", e);
    }

    if (!pass) {
      TestUtil.logErr(
          "Please specify host & port of web server " + "in config properties: "
              + WEBSERVERHOSTPROP + ", " + WEBSERVERPORTPROP);
      throw new Fault("setup failed:");
    }

    logMsg("setup ok");
  }

  public void cleanup() throws Fault {
    logMsg("cleanup ok");
  }

  /*
   * @testName: HandlerChainOnProviderTest
   *
   * @assertion_ids: JAXWS:SPEC:9009.2
   *
   * @test_Strategy: Use a handler that is specified on the Provider and see
   * that it transforms the body
   */
  public void HandlerChainOnProviderTest() throws Fault {
    TestUtil.logMsg("HandlerChainOnProviderTest");
    boolean pass = true;
    String expected1 = "OutboundServerLogicalHandler";
    String expected2 = "InboundServerLogicalHandler";
    String expected3 = "InboundServerSOAPHandler";
    String expected4 = "OutboundServerSOAPHandler";

    HelloRequest helloReq = null;
    try {
      helloReq = of.createHelloRequest();
      helloReq.setArgument("HandlerChainOnProviderTest");
    } catch (Exception e) {
      e.printStackTrace();
    }
    HelloResponse helloRes = null;
    try {
      dispatchJaxb = createDispatchJAXB();
      helloRes = (HelloResponse) dispatchJaxb.invoke(helloReq);
      String result = helloRes.getArgument();
      TestUtil.logMsg("Return value = " + result);
      if (result.indexOf(expected1) == -1) {
        pass = false;
        TestUtil.logErr("The value:" + expected1 + " was not found ");
        TestUtil.logErr("in the result:" + result);
      }
      if (result.indexOf(expected2) == -1) {
        pass = false;
        TestUtil.logErr("The value:" + expected2 + " was not found ");
        TestUtil.logErr("in the result:" + result);
      }
      if (result.indexOf(expected3) == -1) {
        pass = false;
        TestUtil.logErr("The value:" + expected3 + " was not found ");
        TestUtil.logErr("in the result:" + result);
      }
      if (result.indexOf(expected4) == -1) {
        pass = false;
        TestUtil.logErr("The value:" + expected4 + " was not found ");
        TestUtil.logErr("in the result:" + result);
      }
    } catch (Throwable t) {
      t.printStackTrace();
      throw new Fault(t.toString());
    }

    if (!pass)
      throw new Fault("HandlerChainOnProviderTest failed");
  }

}
